@@ -8,7 +8,7 @@ from airflow_commons.sql_resources.bigquery import (
     GET_PRIMITIVE_COLUMN_NAMES_SQL_FILE,
 )
 from airflow_commons.utils.file_utils import read_sql
-from airflow_commons.glossary import COMMA
+from airflow_commons.glossary import COMMA, SQL_QUOTATION
 
 MEGABYTES_BILLED_DENOMINATOR = 2 ** 20
 AVAILABLE_COLUMN_NAMES = ["column_name", "table_name"]
@@ -148,10 +148,12 @@ def query_information_schema(
     :param kwargs:
     :return: requested field as a list
     """
-    if requested_column_name == "column_name":
-        sql = read_sql(GET_COLUMN_NAMES_SQL_FILE, **kwargs)
-    elif requested_column_name == "table_name":
+    if requested_column_name == "table_name":
         sql = read_sql(GET_TABLE_NAMES_SQL_FILE, **kwargs)
+        df_columns = select(client, sql, location=location, timeout=timeout)
+        return df_columns[requested_column_name].to_list()
+    elif requested_column_name == "column_name":
+        sql = read_sql(GET_COLUMN_NAMES_SQL_FILE, **kwargs)
     elif requested_column_name == "primitive_column_name":
         sql = read_sql(GET_PRIMITIVE_COLUMN_NAMES_SQL_FILE, **kwargs)
     else:
@@ -162,6 +164,9 @@ def query_information_schema(
             + COMMA.join(i for i in AVAILABLE_COLUMN_NAMES)
         )
     df_columns = select(client, sql, location=location, timeout=timeout)
+    df_columns[requested_column_name] = (
+        SQL_QUOTATION + df_columns[requested_column_name] + SQL_QUOTATION
+    )
     return df_columns[requested_column_name].to_list()
 
 
